==> gitlab_17.3.5.orig.tar.bz2: gitlab-foss-v17.3.5/spec/lib/banzai/filter/concerns/timeout_filter_handler_spec.rb <==
# frozen_string_literal: true

require 'spec_helper'

RSpec.describe Banzai::Filter::Concerns::TimeoutFilterHandler, feature_category: :team_planning do
  include FilterSpecHelper

  context 'when subclassed from HTML filter' do
    before do
      stub_const 'TimeoutTest', Class.new(HTML::Pipeline::Filter)
      TimeoutTest.class_eval { include Banzai::Filter::Concerns::TimeoutFilterHandler }
    end

    let(:described_class) { TimeoutTest }

    it_behaves_like 'a filter timeout' do
      let(:text) { '<p>some text</p>' }
    end

    it 'raises NotImplementedError' do
      expect { filter('test') }.to raise_error NotImplementedError
    end
  end

  context 'when subclassed from Text filter' do
    before do
      stub_const 'TimeoutTest', Class.new(HTML::Pipeline::TextFilter)
      TimeoutTest.class_eval { include Banzai::Filter::Concerns::TimeoutFilterHandler }
    end

    let(:described_class) { TimeoutTest }

    it_behaves_like 'a filter timeout' do
      let(:text) { '<p>some text</p>' }
    end

    it 'raises NotImplementedError' do
      expect { filter('test') }.to raise_error NotImplementedError
    end
  end

  context 'when DISABLE_BANZAI_TIMEOUT set' do
    before do
      stub_env('DISABLE_BANZAI_TIMEOUT' => '1')
      stub_const 'TimeoutTest', Class.new(HTML::Pipeline::Filter)
      TimeoutTest.class_eval { include Banzai::Filter::Concerns::TimeoutFilterHandler }
    end

    let(:described_class) { TimeoutTest }

    it_behaves_like 'not a filter timeout' do
      let(:text) { '<p>some text</p>' }
    end
  end
end

==> gitlab_17.6.5.orig.tar.bz2: gitlab-foss-v17.6.5/spec/lib/banzai/filter/concerns/timeout_filter_handler_spec.rb <==
# frozen_string_literal: true

require 'spec_helper'

RSpec.describe Banzai::Filter::Concerns::TimeoutFilterHandler, feature_category: :markdown do
  include FilterSpecHelper

  context 'when subclassed from HTML filter' do
    before do
      stub_const 'TimeoutTest', Class.new(HTML::Pipeline::Filter)
      TimeoutTest.class_eval { include Banzai::Filter::Concerns::TimeoutFilterHandler }
    end

    let(:described_class) { TimeoutTest }

    it_behaves_like 'a filter timeout' do
      let(:text) { '<p>some text</p>' }
    end

    it 'raises NotImplementedError' do
      expect { filter('test') }.to raise_error NotImplementedError
    end
  end

  context 'when subclassed from Text filter' do
    before do
      stub_const 'TimeoutTest', Class.new(HTML::Pipeline::TextFilter)
      TimeoutTest.class_eval { include Banzai::Filter::Concerns::TimeoutFilterHandler }
    end

    let(:described_class) { TimeoutTest }

    it_behaves_like 'a filter timeout' do
      let(:text) { '<p>some text</p>' }
    end

    it 'raises NotImplementedError' do
      expect { filter('test') }.to raise_error NotImplementedError
    end
  end

  context 'when GITLAB_DISABLE_MARKDOWN_TIMEOUT set' do
    before do
      stub_env('GITLAB_DISABLE_MARKDOWN_TIMEOUT' => '1')
      stub_const 'TimeoutTest', Class.new(HTML::Pipeline::Filter)
      TimeoutTest.class_eval { include Banzai::Filter::Concerns::TimeoutFilterHandler }
    end

    let(:described_class) { TimeoutTest }

    it_behaves_like 'not a filter timeout' do
      let(:text) { '<p>some text</p>' }
    end
  end
end
